@@ -1,14 +1,12 @@
 #
 # Graph::Reader - perl base class for Graph file format readers
 #
-# $Id: Reader.pm,v 1.2 2001/11/11 14:21:41 neilb Exp $
-#
 package Graph::Reader;
 
 use strict;
+use warnings;
 
-use vars qw($VERSION);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+our $VERSION = '2.01';
 
 use IO::File;
 use Graph;
@@ -65,18 +63,18 @@ sub read_graph
 
     if (ref $filename)
     {
-	$self->_read_graph($graph, $filename);
+        $self->_read_graph($graph, $filename);
     }
     else
     {
-	$FILE = IO::File->new("< $filename");
-	if (not defined $FILE)
-	{
-	    warn "couldn't read from $filename: $!\n";
-	    return 0;
-	}
-	$self->_read_graph($graph, $FILE);
-	$FILE->close();
+        $FILE = IO::File->new("< $filename");
+        if (not defined $FILE)
+        {
+            warn "couldn't read from $filename: $!\n";
+            return 0;
+        }
+        $self->_read_graph($graph, $FILE);
+        $FILE->close();
     }
 
     return $graph;
@@ -92,17 +90,17 @@ Graph::Reader - base class for Graph file format readers
 
 =head1 SYNOPSIS
 
-    package Graph::Reader::MyFormat;
-    use Graph::Reader;
-    use vars qw(@ISA);
-    @ISA = qw(Graph::Reader);
+  package Graph::Reader::MyFormat;
+  use Graph::Reader;
+  use vars qw(@ISA);
+  @ISA = qw(Graph::Reader);
     
-    sub _read_graph
-    {
-        my ($self, $graph, $FILE) = @_;
-        
-        # read $FILE and populate $graph
-    }
+  sub _read_graph
+  {
+    my ($self, $graph, $FILE) = @_;
+    
+    # read $FILE and populate $graph
+  }
 
 =head1 DESCRIPTION
 
@@ -124,7 +122,7 @@ is a virtual method, or whatever the correct lingo is.
 You're not meant to call this on the base class,
 it is inherited by the subclasses. Ie if you do something like:
 
-    $reader = Graph::Reader->new();
+  $reader = Graph::Reader->new();
 
 It will throw an exception.
 
@@ -132,7 +130,7 @@ It will throw an exception.
 
 Read a graph from the specified file:
 
-    $graph = $reader->read_graph($file);
+  $graph = $reader->read_graph($file);
 
 The C<$file> argument can either be a filename,
 or a filehandle for a previously opened file.
@@ -144,26 +142,26 @@ which subclasses B<Graph::Reader>. For example, suppose
 DGF is a directed graph format - create a B<Graph::Reader::DGF> module,
 with the following structure:
 
-    package Graph::Reader::DGF;
-    
-    use Graph::Reader;
-    use vars qw(@ISA);
-    @ISA = qw(Graph::Reader);
+  package Graph::Reader::DGF;
+  
+  use Graph::Reader;
+  use vars qw(@ISA);
+  @ISA = qw(Graph::Reader);
 
-    sub _read_graph
+  sub _read_graph
+  {
+    my $self  = shift;
+    my $graph = shift;
+    my $FILE  = shift;
+        
+    while (<$FILE>)
     {
-        my $self  = shift;
-        my $graph = shift;
-        my $FILE  = shift;
-        
-        while (<$FILE>)
-        {
-	}
-        
-        return 1;
     }
+  
+    return 1;
+  }
     
-    1;
+  1;
 
 Note the leading underscore on the B<_read_graph()> method.
 The base class provides the public method, and invokes the
@@ -175,21 +173,21 @@ which will be invoked by the base class's constructor.
 You should invoke the superclass's initialiser as well,
 as follows:
 
-    sub _init
-    {
-        my $self = shift;
+  sub _init
+  {
+    my $self = shift;
     
-        $self->SUPER::_init();
+    $self->SUPER::_init();
         
-        # your initialisation here
-    }
+    # your initialisation here
+  }
 
 Someone can then use your class as follows:
 
-    use Graph::Reader::DGF;
-    
-    $reader = Graph::Reader::DGF->new();
-    $graph = $reader->read_graph('foo.dgf');
+  use Graph::Reader::DGF;
+  
+  $reader = Graph::Reader::DGF->new();
+  $graph = $reader->read_graph('foo.dgf');
 
 =head1 SEE ALSO
 
@@ -222,7 +220,7 @@ Neil Bowers E<lt>neil@bowers.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001, Neil Bowers. All rights reserved.
+Copyright (c) 2001-2012, Neil Bowers. All rights reserved.
 Copyright (c) 2001, Canon Research Centre Europe. All rights reserved.
 
 This script is free software; you can redistribute it and/or modify
