@@ -1,17 +1,16 @@
 #
 # Graph::Writer::HTK - perl module for writing a Graph as an HTK lattice
 #
-# $Id: HTK.pm,v 1.2 2001/11/11 14:24:37 neilb Exp $
-#
 package Graph::Writer::HTK;
 
+use strict;
+use warnings;
+
 #=======================================================================
 #=======================================================================
 
-use Graph::Writer;
-use vars qw(@ISA $VERSION);
-@ISA = qw(Graph::Writer);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+use parent 'Graph::Writer';
+our $VERSION = '2.01';
 
 my @graph_attributes = qw(base lmname lmscale wdpenalty);
 
@@ -60,64 +59,71 @@ sub _write_graph
     print $FILE "N=",int($graph->vertices),"  L=",int($graph->edges),"\n";
 
     $node_num = 0;
-    foreach $v ($graph->vertices)
+    foreach $v (sort $graph->vertices)
     {
-	$v2n{$v} = $node_num;
-	print $FILE "I=$node_num";
-	foreach my $field (keys %node_attributes)
-	{
-	    foreach my $attr (@{ $node_attributes{$field} })
-	    {
-		if ($graph->has_attribute($attr, $v))
-		{
-		    print $FILE "  $field=", $graph->get_attribute($attr, $v);
-		    last;
-		}
-	    }
-	}
-	print $FILE "\n";
-	++$node_num;
+        $v2n{$v} = $node_num;
+        print $FILE "I=$node_num";
+        foreach my $field (keys %node_attributes)
+        {
+            foreach my $attr (@{ $node_attributes{$field} })
+            {
+                if ($graph->has_vertex_attribute($v, $attr))
+                {
+                    print $FILE "  $field=",
+                                $graph->get_vertex_attribute($v, $attr);
+                    last;
+                }
+            }
+        }
+        print $FILE "\n";
+        ++$node_num;
     }
 
     $edge_num = 0;
-    my @edges = $graph->edges;
-    while (@edges > 0)
+    foreach my $edge (sort _by_vertex $graph->edges)
     {
-	($from, $to) = splice(@edges, 0, 2);
-	print $FILE "J=$edge_num  S=", $v2n{$from}, "  E=", $v2n{$to};
-	foreach my $field (keys %edge_attributes)
-	{
-	    foreach my $attr (@{ $edge_attributes{$field} })
-	    {
-		if ($graph->has_attribute($attr, $from, $to))
-		{
-		    print $FILE "  $field=",
-				$graph->get_attribute($attr, $from, $to);
-		    last;
-		}
-	    }
-	}
-	print $FILE "\n";
-	++$edge_num;
+        ($from, $to) = @$edge;
+        print $FILE "J=$edge_num  S=", $v2n{$from}, "  E=", $v2n{$to};
+        foreach my $field (keys %edge_attributes)
+        {
+            foreach my $attr (@{ $edge_attributes{$field} })
+            {
+                if ($graph->has_edge_attribute($from, $to, $attr))
+                {
+                    print $FILE "  $field=",
+                                $graph->get_vertex_attribute($from, $to, $attr);
+                    last;
+                }
+            }
+        }
+        print $FILE "\n";
+        ++$edge_num;
     }
 
     return 1;
 }
 
+
+sub _by_vertex
+{
+    return $a->[0].$a->[1] cmp $b->[0].$b->[1];
+}
+
+
 1;
 
 __END__
 
 =head1 NAME
 
-Graph::Writer::HTK - write an perl Graph out as an HTK lattice file
+Graph::Writer::HTK - write a perl Graph out as an HTK lattice file
 
 =head1 SYNOPSIS
 
-    use Graph::Writer::HTK;
-    
-    $writer = Graph::Reader::HTK->new();
-    $reader->write_graph($graph, 'mylattice.lat');
+  use Graph::Writer::HTK;
+  
+  $writer = Graph::Reader::HTK->new();
+  $reader->write_graph($graph, 'mylattice.lat');
 
 =head1 DESCRIPTION
 
@@ -149,7 +155,7 @@ Neil Bowers E<lt>neil@bowers.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2000, Neil Bowers. All rights reserved.
+Copyright (c) 2000-2012, Neil Bowers. All rights reserved.
 Copyright (c) 2000, Canon Research Centre Europe. All rights reserved.
 
 This module is free software; you can redistribute it and/or modify
